@@ -1,7 +1,7 @@
 from django.db.models.signals import post_init, post_save, post_delete
 from django.apps.registry import apps
 
-from .settings import MODELS_FOR_LOGGING, MODELS_FOR_EXCLUDE
+from .settings import MODELS_FOR_LOGGING, MODELS_FOR_EXCLUDE, LOGGING_DATABASE
 from .signals import init_model_attrs, save_model, delete_model
 
 
@@ -20,4 +20,4 @@ def models_register():
         for model in registered_models:
             post_init.connect(init_model_attrs, sender=model)
             post_save.connect(save_model, sender=model)
-            post_delete.connect(delete_model, sender=model)
\ No newline at end of file
+            post_delete.connect(delete_model, sender=model)
